Class: PoiseService::Resources::PoiseServiceUser::Resource

Inherits:
Chef::Resource
  • Object
show all
Includes:
Poise
Defined in:
lib/poise_service/resources/poise_service_user.rb

Overview

A poise_service_user resource to create service users/groups.

Examples:

poise_service_user 'myapp' do
  home '/var/tmp'
  group 'nogroup'
end

Since:

  • 1.0.0

Provides:

  • poise_service_user

Actions:

  • create

  • remove

Instance Attribute Summary collapse

Instance Attribute Details

#gid ⇒ Integer

GID of the group to create. Optional, if not set the GID will be allocated automatically.

Returns:



66
# File 'lib/poise_service/resources/poise_service_user.rb', line 66

attribute(:gid, kind_of: Integer)

#group ⇒ String, false

Name of the group to create. Defaults to the name of the user, except on Windows where it defaults to false. Set to false to disable group creation.

Returns:



56
# File 'lib/poise_service/resources/poise_service_user.rb', line 56

attribute(:group, kind_of: [String, FalseClass], default: lazy { default_group })

#home ⇒ String

Home directory of the user. This directory will not be created if it does not exist. Optional.

Returns:



76
# File 'lib/poise_service/resources/poise_service_user.rb', line 76

attribute(:home, kind_of: String)

#shell ⇒ String

Login shell for the user. Optional, if not set the shell will be determined automatically.

Returns:



71
# File 'lib/poise_service/resources/poise_service_user.rb', line 71

attribute(:shell, kind_of: String, default: lazy { default_shell })

#uid ⇒ Integer

UID of the user to create. Optional, if not set the UID will be allocated automatically.

Returns:



61
# File 'lib/poise_service/resources/poise_service_user.rb', line 61

attribute(:uid, kind_of: Integer)

#user ⇒ String

Name of the user to create. Defaults to the name of the resource.

Returns:



50
# File 'lib/poise_service/resources/poise_service_user.rb', line 50

attribute(:user, kind_of: String, name_attribute: true)